@@ -6,6 +6,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "encodingprofilesdialog.h"
 #include "core.h"
+#include "dialogs/wizard.h"
 #include "kdenlivesettings.h"
 #include "profiles/profilemodel.hpp"
 #include "profiles/profilerepository.hpp"
@@ -141,7 +142,7 @@ void EncodingProfilesDialog::slotAddProfile()
         pext->setText(profilestr.section(QLatin1Char(';'), 1, 1));
     }
     if (d->exec() == QDialog::Accepted) {
-        m_configGroup->writeEntry(pname->text(), pparams->toPlainText() + QLatin1Char(';') + pext->text());
+        m_configGroup->writeEntry(pname->text(), QString(pparams->toPlainText() + QLatin1Char(';') + pext->text()));
         slotLoadProfiles();
     }
     delete d;
@@ -175,7 +176,7 @@ void EncodingProfilesDialog::slotEditProfile()
         pparams->setFocus();
     }
     if (d->exec() == QDialog::Accepted) {
-        m_configGroup->writeEntry(pname->text(), pparams->toPlainText().simplified() + QLatin1Char(';') + pext->text());
+        m_configGroup->writeEntry(pname->text(), QString(pparams->toPlainText().simplified() + QLatin1Char(';') + pext->text()));
         slotLoadProfiles();
     }
     delete d;
@@ -202,6 +203,9 @@ EncodingProfilesChooser::EncodingProfilesChooser(QWidget *parent, EncodingProfil
     buttonInfo->setCheckable(true);
     buttonInfo->setIcon(QIcon::fromTheme(QStringLiteral("help-about")));
     buttonConfigure->setToolTip(i18n("Show Profile Parameters"));
+    buttonConfigure->setWhatsThis(
+        xi18nc("@info:whatsthis", "Opens a window with encoding profiles and their parameters. From here you can create, change, delete and download profiles "
+                                  "used for timeline preview, proxy generation, and video, screen and decklink capture."));
 
     m_info = new QPlainTextEdit();
     m_info->setReadOnly(true);
@@ -251,8 +255,8 @@ void EncodingProfilesChooser::loadEncodingProfiles()
     QString currentItem = m_profilesCombo->currentText();
     m_profilesCombo->clear();
     if (m_showAutoItem) {
-        if (m_type == EncodingProfilesManager::TimelinePreview && (KdenliveSettings::nvencEnabled() || KdenliveSettings::vaapiEnabled())) {
-            m_profilesCombo->addItem(QIcon::fromTheme(QStringLiteral("speedometer")), i18n("Automatic"));
+        if (m_type == EncodingProfilesManager::TimelinePreview && !KdenliveSettings::supportedHWCodecs().isEmpty()) {
+            m_profilesCombo->addItem(QIcon::fromTheme(QStringLiteral("speedometer")), i18n("Automatic (%1)", Wizard::getHWCodecFriendlyName()));
         } else {
             m_profilesCombo->addItem(i18n("Automatic"));
         }
@@ -340,8 +344,8 @@ void EncodingTimelinePreviewProfilesChooser::loadEncodingProfiles()
     QString currentItem = m_profilesCombo->currentText();
     m_profilesCombo->clear();
     if (m_showAutoItem) {
-        if (KdenliveSettings::nvencEnabled() || KdenliveSettings::vaapiEnabled()) {
-            m_profilesCombo->addItem(QIcon::fromTheme(QStringLiteral("speedometer")), i18n("Automatic"));
+        if (!KdenliveSettings::supportedHWCodecs().isEmpty()) {
+            m_profilesCombo->addItem(QIcon::fromTheme(QStringLiteral("speedometer")), i18n("Automatic (%1)", Wizard::getHWCodecFriendlyName()));
         } else {
             m_profilesCombo->addItem(i18n("Automatic"));
         }
@@ -351,23 +355,29 @@ void EncodingTimelinePreviewProfilesChooser::loadEncodingProfiles()
     KConfigGroup group(&conf, EncodingProfilesManager::configGroupName(m_type));
     QMap<QString, QString> values = group.entryMap();
     QMapIterator<QString, QString> i(values);
+    const QStringList allHWCodecs = Wizard::codecs();
     while (i.hasNext()) {
         i.next();
         if (!i.key().isEmpty()) {
-            // We filter out incompatible profiles
-            if (i.value().contains(QLatin1String("nvenc"))) {
-                if (KdenliveSettings::nvencEnabled()) {
-                    m_profilesCombo->addItem(QIcon::fromTheme(QStringLiteral("speedometer")), i.key(), i.value());
+            // We filter out incompatible profiles, find out vcodec if mentionned
+            QString itemCodec;
+            QStringList values = i.value().split(QLatin1Char(' '));
+            for (auto &v : values) {
+                if (v.startsWith(QLatin1String("vcodec=")) || v.startsWith(QLatin1String("codec:v=")) || v.startsWith(QLatin1String("c:v="))) {
+                    itemCodec = v.section(QLatin1Char('='), 1);
+                    break;
                 }
-                continue;
             }
-            if (i.value().contains(QLatin1String("vaapi"))) {
-                if (KdenliveSettings::vaapiEnabled()) {
-                    m_profilesCombo->addItem(QIcon::fromTheme(QStringLiteral("speedometer")), i.key(), i.value());
+            if (!itemCodec.isEmpty()) {
+                if (allHWCodecs.contains(itemCodec)) {
+                    // This is an HW codec, chech if supported
+                    if (KdenliveSettings::supportedHWCodecs().contains(itemCodec)) {
+                        m_profilesCombo->addItem(QIcon::fromTheme(QStringLiteral("speedometer")), i.key(), i.value());
+                    }
+                    continue;
                 }
-                continue;
+                m_profilesCombo->addItem(i.key(), i.value());
             }
-            m_profilesCombo->addItem(i.key(), i.value());
         }
     }
     if (!currentItem.isEmpty()) {
