@@ -141,14 +141,14 @@ void SpeedTask::start(QObject *object, bool force)
                 qDebug() << "=== INVALID SUBCLIP DATA: " << id;
                 continue;
             }
-            owner = {ObjectType::BinClip, binData.first().toInt(), QUuid()};
+            owner = ObjectId(ObjectType::BinClip, binData.first().toInt(), QUuid());
             binClip = pCore->projectItemModel()->getClipByBinID(binData.first());
             if (binClip) {
                 task = new SpeedTask(owner, destinations.at(id), binData.at(1).toInt(), binData.at(2).toInt(), filterParams, binClip.get());
             }
         } else {
             // Process full clip
-            owner = {ObjectType::BinClip, id.toInt(), QUuid()};
+            owner = ObjectId(ObjectType::BinClip, id.toInt(), QUuid());
             binClip = pCore->projectItemModel()->getClipByBinID(id);
             if (binClip) {
                 task = new SpeedTask(owner, destinations.at(id), -1, -1, filterParams, binClip.get());
